# Running the unit tests

The tests can be run this way:

    cd python3-flightgear
    python3 -m unittest

If you want to be more specific:

    cd python3-flightgear
    python3 -m unittest tests.test_sgprops
    python3 -m unittest tests.test_catalog
    python3 -m unittest tests.test_catalog.UpdateCatalogTests
    python3 -m unittest tests.test_catalog.UpdateCatalogTests.test_scan_set
    ...

Use the `-v` option after `python3 -m unittest` for verbose mode. For more
information, please refer to the
[documentation of the unittest module](https://docs.python.org/3/library/unittest.html).
